@@ -3,5 +3,13 @@ from .week_tIme_window import WeekTimeWindow
 from .military_time import MilitaryTime
 from .time_window import TimeWindow
 from .weekday import WeekDay
+from .session_window import SessionWindow
 
-__all__ = ["WeekTime", "WeekTimeWindow", "MilitaryTime", "TimeWindow", "WeekDay"]
+__all__ = [
+    "WeekTime",
+    "WeekTimeWindow",
+    "MilitaryTime",
+    "TimeWindow",
+    "WeekDay",
+    "SessionWindow",
+]
