@@ -1,6 +1,6 @@
-from pytz import timezone, utc
+from pytz import timezone, utc, BaseTzInfo
 
-from shuttl_time import WeekTime, WeekTimeWindow
+from shuttl_time import WeekTime, WeekTimeWindow, SessionWindow
 from shuttl_time.military_time import MilitaryTime
 from shuttl_time.weekday import WeekDay
 
@@ -28,3 +28,12 @@ def week_time_dm(
 def week_time_window_dm(start: WeekTime = None, end: WeekTime = None) -> WeekTimeWindow:
     start = start or week_time_dm()
     return WeekTimeWindow(start=start, end=end or start)
+
+
+def session_window_dm(
+    from_time: int = 1000, to_time: int = 1200, timezone: BaseTzInfo = utc
+) -> SessionWindow:
+    return SessionWindow(
+        from_time=MilitaryTime(from_time, timezone),
+        to_time=MilitaryTime(to_time, timezone),
+    )
